@@ -32,11 +32,7 @@ namespace Palapeli
 
 		protected:
 			void mouseMoveEvent(QMouseEvent* event) override;
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
             void enterEvent(QEnterEvent* event) override;
-#else
-            void enterEvent(QEvent* event) override;
-#endif
             void leaveEvent(QEvent* event) override;
 			void resizeEvent(QResizeEvent* event) override;
 			void moveEvent(QMoveEvent *event) override;
