@@ -1,20 +1,8 @@
-/***************************************************************************
- *   Copyright 2009, 2010 Stefan Majewsky <majewsky@gmx.net>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009, 2010 Stefan Majewsky <majewsky@gmx.net>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef PALAPELI_SCENE_H
 #define PALAPELI_SCENE_H
@@ -39,8 +27,9 @@ namespace Palapeli
 	class Scene : public QGraphicsScene
 	{
 		Q_OBJECT
+		friend class GamePlay;
 		public:
-			explicit Scene(QObject* parent = 0);
+			explicit Scene(QObject* parent = nullptr);
 
 			void addPieceToList(Palapeli::Piece* piece);
 			void addPieceItemsToScene();
